import { EventEmitter, TemplateRef } from '@angular/core';
import { ButtonSizes } from '../button/button.types';
import { IconProp } from '@fortawesome/fontawesome-svg-core';
import { CdkDragDrop } from '@angular/cdk/drag-drop';
import { Observable } from 'rxjs';
export interface ListEvent<T> {
    index?: number;
    item: T;
}
export declare class ListComponent {
    /***
     * Create actionable list group items with hover, disabled, and active states
     */
    actionable: boolean;
    /**
     * Actives the option to select multiple itens on list
     * This options is enabled by default on actionable lists
     */
    selectMultiple: boolean;
    /**
     * Buttons Options
     */
    btnAddText: string;
    btnSize: ButtonSizes;
    btnDirection: 'column' | 'row';
    /***
     * Adds a class list-group-flush to remove some borders and rounded corners
     * to render list group items edge-to-edge in a parent container
     */
    flush: boolean;
    /**
     * Activates the option to sort list
     */
    sortable: boolean;
    draggable: boolean;
    /**
     * Icon that shows for each item list
     */
    icon: IconProp;
    /**
     * List used to iterate
     */
    list: any[];
    /**
     * Input to set when component is hidden
     * and a loading is displayed
     */
    loading: boolean;
    /**
     * Properties of list objects
     */
    propPrimary: string;
    propIcon: string;
    propTitle: string;
    propText: string | string[];
    propOrder: string;
    /**
     * Activates additional features
     */
    showToolbar: boolean;
    showOrders: boolean;
    /**
     * Input function to validate order changes
     * Function must return a observable boolean result
     * If it was not defined will always move items
     */
    orderValidator: (orders: any) => Observable<boolean>;
    /**
     * Output Events
     */
    addItem: EventEmitter<{}>;
    clickItem: EventEmitter<ListEvent<any>>;
    editItem: EventEmitter<ListEvent<any>>;
    removeItem: EventEmitter<ListEvent<any>>;
    removeItems: EventEmitter<ListEvent<any[]>>;
    buttons: TemplateRef<any>;
    toolbarButtons: TemplateRef<any>;
    busy: boolean;
    isArray: (arg: any) => arg is any[];
    totalSelected: number;
    /**
     * Handles the click event to output item was clicked
     */
    click(event: MouseEvent, index: number, item: any): void;
    /**
     * Output when users clicks on edit button
     */
    edit(index: number, item: any): void;
    /**
     * Output when users clicks on remove button
     */
    remove(index: number, item: any): void;
    /**
     * Output when users clicks on remove all button
     * this emit all items selected
     */
    removeSelected(): void;
    drop(event: CdkDragDrop<string[]>): void;
    getOrderChanges(list: any[]): any[];
    setOrderChanges(list: any[]): void;
}
